	PROGRAM PROG155

C	BY A.K. COKER
C	A.K.C. TECHNOLOGY 2015
C	U.K.

C	******************************************************************
C	*  THE SIZING OF AIR-COOLED HEAT EXCHANGERS.
C	*  THE PROGRAM PERFORMS PRELIMINARY AIR-COOLER DESIGN CALCULATIONS
C	*  WITH A RANGE OF INPUT DATA.
C	*
C	*  THE PROGRAM CALCULATES:
C	*  1.  THE NUMBER OF TUBE ROWS (TUBE BUNDLE DEPTH).
C	*  2.  OUTLET AIR TEMPERATURE.
C	*  3.  LOG MEAN TEMPERATURE DIFFERENCE.
C	*  4.  TOTAL BARE-TUBE SURFACE AREA (BASED ON 1 inch OD TUBING
C	*      ON 2 3/8 inch TRIANGULAR SPACING.).
C	*  5.  COOLER FACE AREA (plan area).
C	*  6.  AIR VELOCITY ACROSS TUBES.
C	*  7.  TOTAL AIR FLOW.
C	*  8.  FAN HORSEPOWER (bhp = brake horsepower).
C	*  9.  TOTAL BUNDLE WEIGHT.
C	* 10.  TUBE BUNDLE WIDTH FOR A GIVEN TUBE LENGTH.
C
C	*  THIS PROGRAM IS BASED ON CORRELATIONS PRESENTED IN ARTICLES BY
C	*  E.C. Smith AND R. Brown.  THE CORRELATIONS PRESENTED BY GRAPHS
C	*  AND TABLES IN THE ORIGINAL ARTICLES AND FITTED TO A SERIES OF
C	*  EQUATION BY W.W. Blackwell ARE USED IN THIS PROGRAM.
C	***********************************************************************
C	*
C	*  R	           = NUMBER OF TUBE ROWS.
C	*  TPI	   = INLET PROCESS FLUID TEMPERATURE, oF.
C	*  TAI	   = INLET AIR TEMPERATURE, oF.
C	*  BTSA        = BARE-TUBE SURFACE AREA BASED ON TUBE OD, ft^2.
C	*  FA	           = FACE AREA OF BUNDLE, ft^2.
C	*  FV	           = FACE VELOCITY OF AIR,ft^2.
C	*  TAO1        = ESTIMATED AIR OUTLET TEMPERATURE, oF.
C	*  U	           = OVERALL HEAT-TRANSFER COEFFICIENT
C		              (BASED ON BARE-TUBE OD) Btu/h.ft^2oF.
C	*  TPO	   = OUTLET PROCESS FLUID TEMPERATURE, oF.
C	*  LMTD       = EFFECTIVE LOG MEAN TEMPERATURE DIFFERENCE, oF.
C	*  Q	           = HEAT LOAD, Btu/h.
C	*  TAO	   = CALCULATED OUTLET AIR TEMPERATURE, oF.
C	*  F	           = AIR FLOW OVER TUBES, std ft^3/min.
C	*  BHP	   = FAN HORSEPOWER, brake horsepower.
C	*  WT	   = AIR-COOLER WEIGHT, lb.
C	*  W        	   = TUBE BUNDLE, WIDTH, ft.
C	*  TL	           = TUBE LENGTH, ft.
C	*  C1,C2,C3,C4,C5,C6,C7,C8,C9,C10 = CONSTANTS
C	***************************************************************

	REAL  LMTD

	OPEN(UNIT=3,FILE='DATA155.DAT',STATUS='OLD',ACTION='READ',
     *	ERR=18)


	OPEN (UNIT =1, FILE='RES155.RES')


C	CONSTANTS USED IN THE PROGRAM


	C1 = 3.1679
	C2 = 3.7948
	C3 = 1.2557
	C4 = 1.0031
	C5 = 720.8542
	C6 = 0.9530
	C7 = 7.4212
	C8 = 12.5342
	C9 = 36.4
	C10 = 9.35

C

C	READ THE INLET PROCESS FLUID TEMPERATURE, oF: TPI
C	READ THE OUTLET PROCESS FLUID TEMPERATURE, oF: TPO
C	READ THE INLET AIR TEMPERATURE, oF: TAI
C	READ THE OVERALL HEAT-TRANSFER COEFFICIENT, Btu/h.ft^2.oF: U
C	READ THE HEAT LOAD, Btu/h.: Q
C	READ THE TUBE LENGTH, ft.: TL


	READ (3, *, ERR=19) TPI, TPO, TAI
	READ (3, *, ERR=19) U, Q, TL
	GO TO 20

 18	WRITE (*, 100)
 100	FORMAT (6X, 'DATA FILE DOES NOT EXIST')
	GO TO 999

 19	WRITE (*, 110)
 110	FORMAT (6X, 'ERROR MESSAGE IN THE DATA VALUE')
	GO TO 999



 20	WRITE (1, 120)
 120	FORMAT (///,20X,'AN AIR-COOLED HEAT EXCHANGER DESIGN',/,78(1H*))

	WRITE (1, 130) TPI, TPO, TAI
 130	FORMAT (6X,'INLET PROCESS FLUID TEMPERATURE, oF:',T60, F8.1,
     *		/,6X,'OUTLET PROCESS FLUID TEMPERATURE, oF:',T60,F8.1,
     *		/,6X,'INLET AIR TEMPERATURE, oF:',T60,F8.1)

	WRITE (1, 140) U, Q, TL
 140	FORMAT (6X,'OVERALL HEAT-TRANSFER COEFFICEINT, Btu/h.ft^2.oF:',
     *		T60, F8.1,/,6X,'HEAT LOAD, Btu/h.:',T60, F12.0,/,6X,
     *		'TUBE LENGTH, ft.:', T60, F8.1)




	WRITE (*, 1000)
 1000	FORMAT (///,20X,'AN AIR-COOLED HEAT EXCHANGER DESIGN',/,78(1H*))

	WRITE (*, 1100) TPI, TPO, TAI
 1100	FORMAT (6X,'INLET PROCESS FLUID TEMPERATURE, oF:',T60, F8.1,
     *		/,6X,'OUTLET PROCESS FLUID TEMPERATURE, oF:',T60,F8.1,
     *		/,6X,'INLET AIR TEMPERATURE, oF:',T60,F8.1)

	WRITE (*, 1200) U, Q, TL
 1200	FORMAT (6X,'OVERALL HEAT-TRANSFER COEFFICEINT, Btu/h.ft^2.oF:',
     *		T60, F8.1,/,6X,'HEAT LOAD, Btu/h.:',T60, F12.0,/,6X,
     *		'TUBE LENGTH, ft.:', T60, F8.1)



C	CALCULATE THE NUMBER OF TUBE ROWS

	R = C1 + C2*(ALOG((TPI-TAI)/U))

C	CALCULATE THE RATIO OF BARE-TUBE SURFACE AREA BASED ON THE
C	TUBE OD TO THE FACE AREA OF BUNDLE , RATIO1=BTSA/FA

	RATIO1 = C3*(R**C4)

C	CALCULATE THE FACE VELOCITY OF AIR, ft/min.

	FV = C5*(C6**R)

	WRITE (1, 150) R, RATIO1, FV
 150	FORMAT (6X,'NUMBER OF TUBE ROWS:',T60,F6.1,/,6X,
     *	'RATIO OF BARE-TUBE SURFACE TO FACE AREA OF BUNDLE:', T60, F6.1,
     *	/, 6X, 'FACE VELOCITY OF AIR, ft./min.:', T60, F8.3)


	WRITE (*, 1300) R, RATIO1, FV
 1300	FORMAT (6X,'NUMBER OF TUBE ROWS:',T60,F6.1,/,6X,
     *	'RATIO OF BARE-TUBE SURFACE TO FACE AREA OF BUNDLE:', T60, F6.1,
     *	/, 6X, 'FACE VELOCITY OF AIR, ft./min.:', T60, F8.3)


C	CALCULATE THE ESTIMATED AIR OUTLET TEMPERATURE, oF: TAO1

	TAO1 = (0.005*U*((TPO+TPI)/2.0-TAI)) + TAI

	WRITE (1, 160) TAO1
 160	FORMAT (6X, 'ESTIMATED AIR OUTLET TEMPERATURE, oF:',T60, F8.3)

	WRITE (*, 1400) TAO1
 1400	FORMAT (6X, 'ESTIMATED AIR OUTLET TEMPERATURE, oF:',T60, F8.3)

C	CALCULATE THE LOG MEAN TEMPERATURE DIFFERENCE, oF: LMTD.

   25	VAL1 = (TPO-TAI)-(TPI-TAO1)
	VAL2 = ALOG((TPO-TAI)/(TPI-TAO1))
	LMTD = VAL1/VAL2

C	CALCULATE BARE-TUBE SURFACE AREA BASED ON TUBE, OD: ft^2: BTSA

	BTSA = Q/(U*LMTD)

C	CALCULATE THE FACE AREA OF BUNDLE, ft^2: FA

	FA = BTSA/RATIO1

	WRITE (1, 170) LMTD, BTSA, FA
 170	FORMAT (6X,'EFFECTIVE LOG MEAN TEMPERATURE DIFFERENCE, oF:',T60,
     *	   F8.3, /, 6X,'BARE-TUBE SURFACE AREA BASED ON TUBE OD, ft^2:',
     *	   T60, F8.1, /, 6X,'FACE AREA OF BUNDLE, ft^2:',T60,F8.1)



	WRITE (*, 1500) LMTD, BTSA, FA
 1500	FORMAT (6X,'EFFECTIVE LOG MEAN TEMPERATURE DIFFERENCE, oF:',T60,
     *	   F8.3, /, 6X,'BARE-TUBE SURFACE AREA BASED ON TUBE OD, ft^2:',
     *	   T60, F8.1, /, 6X,'FACE AREA OF BUNDLE, ft^2:',T60,F8.1)

C	CALCULATED OUTLET AIR TEMPERATURE, oF: TAO

	TAO = (Q/(FA*FV*1.08)) + TAI

	WRITE (1, 180) TAO
 180	FORMAT (6X,'CALCULATED OUTLET AIR TEMPERATURE, oF:', T60, F8.3)


	WRITE (*, 1600) TAO
 1600	FORMAT (6X,'CALCULATED OUTLET AIR TEMPERATURE, oF:', T60, F8.3)


C	A NECESSARY CONDITION FOR SIZING AN AIR-COOLED EXCHANGER.
C	CHECK WHETHER THE DIFFERENCE BETWEEN THE CALCULATED AIR OUTLET
C	TEMPERATURE AND THE ESTIMATED AIR OUTLET TEMPERATURE IS GREATER
C	THAN/OR EQUAL TO 0.5 (i.e. (TAO-TAO1) .GE. 0.5))

C	IF THE DIFFERENCE IS GREATER THAN OR EQUAL TO 0.5, THEN SET THE
C	ESTIMATED AIR OUTLET TEMPERATURE EQUAL TO THE CALCULATED AIR
C	OUTLET TEMPERATURE AND REPEAT THE CALCULATION FROM THE LOG MEAN
C	TEMPERATURE DIFFERENCE.

	IF ((TAO-TAO1) .GE. 0.5) THEN

	WRITE (1, 190)
 190	FORMAT (6X,'THE DIFFERENCE BETWEEN THE CALCULATED AIR', /, 6X,
     *	'OUTLET TEMPERATURE AND THE ESTIMATED AIR OUTLET', /, 6X,
     *	'TEMPERATURE IS GREATER THAN 0.5',T60,'TAO-TAO1 >0.5')



	WRITE (*, 1700)
 1700	FORMAT (6X,'THE DIFFERENCE BETWEEN THE CALCULATED AIR', /, 6X,
     *	'OUTLET TEMPERATURE AND THE ESTIMATED AIR OUTLET', /, 6X,
     *	'TEMPERATURE IS GREATER THAN 0.5',T60,'TAO-TAO1 >0.5')



	TAO1 = TAO
	GO TO 25
	ELSE
	ENDIF

	WRITE (1, 200) BTSA,FA
 200	FORMAT (6X,'CALCULATED BARE-TUBE SURFACE AREA', /, 6X,
     *	       'BASED ON TUBE OUTSIDE DIAMETER, ft^2:', T60, F8.1,
     *	       /,6X,'FACE AREA OF BUNDLE, ft^2:', T60, F8.1)



	WRITE (*, 1800) BTSA,FA
 1800	FORMAT (6X,'CALCULATED BARE-TUBE SURFACE AREA', /, 6X,
     *	       'BASED ON TUBE OUTSIDE DIAMETER, ft^2:', T60, F8.1,
     *	       /,6X,'FACE AREA OF BUNDLE, ft^2:', T60, F8.1)


C	CALCULATE AIR FLOW OVER TUBES, std ft^3/min.: F

	F = FA*FV

C	CALCULATE FAN HORSEPOWER: BHP

	BHP = BTSA/(C7+(C8*R))

C	CALCULATE AIR-COOLER WEIGHT, lb: WT.

	WT = FA*(C9+(C10*R))

C	CALCULATE TUBE BUNDLE WIDTH, ft: W

	W = FA/TL
C
	WRITE (1, 210) F, BHP
 210	FORMAT (6X,'AIR FLOW OVER TUBES, std.ft^3/min.:', T60, F9.0,
     *	/, 6X, 'FAN HORSEPOWER, bhp:', T60, F8.1)

	WRITE (1, 220) WT, W
 220	FORMAT (6X,'AIR-COOLER WEIGHT, lb:', T60, F9.1, /, 6X,
     *		'TUBE BUNDLE WIDTH, ft.:',T60,F8.1)

	WRITE (1, 230)
 230	FORMAT (1H ,78(1H-))

	WRITE (*, 1900) F, BHP
 1900	FORMAT (6X,'AIR FLOW OVER TUBES, std.ft^3/min.:', T60, F9.0,
     *	/, 6X, 'FAN HORSEPOWER, bhp:', T60, F8.1)

	WRITE (*, 2000) WT, W
 2000	FORMAT (6X,'AIR-COOLER WEIGHT, lb:', T60, F9.1, /, 6X,
     *		'TUBE BUNDLE WIDTH, ft.:',T60,F8.1)

	WRITE (*, 2100)
 2100	FORMAT (1H ,78(1H-))


	CLOSE (3, STATUS='KEEP')
	CLOSE (1)
  999	STOP
	END
